SuffixImp class abstract

Inheritance
Implementers

Constructors

SuffixImp({String? title, double? constraintsHeight, double? constraintsWidth, VoidCallback? onTap, String? iconImage, IconData? iconData, Color? color, double? size, Widget? widget, double? fontSize, FontWeight? fontWeight, double? scale})
const

Properties

color Color?
final
constraintsHeight double?
final
constraintsWidth double?
final
fontSize double?
final
fontWeight FontWeight?
final
getBoxConstraints BoxConstraints?
no setter
hashCode int
The hash code for this object.
no setterinherited
iconData IconData?
final
iconImage String?
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double?
final
size double?
final
title String?
final
widget Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(BuildContext context) Widget?
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited